#
# spec file for package python-pylibmc
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pylibmc
VCS: https://src.suse.de/SLFO-pool/python-pylibmc#82c96118b235ee4d4a66186bf59e1a7d8cd18dddb936162616748336b185bca2
Version:        1.6.3
Release:        160000.1.15
Summary:        memcached client for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/lericson/pylibmc
Source:         https://files.pythonhosted.org/packages/source/p/pylibmc/pylibmc-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  libmemcached-devel
BuildRequires:  memcached
BuildRequires:  python-rpm-macros
BuildRequires:  zlib-devel
%python_subpackages

%description
pylibmc is a Python client for (lib)memcached written in C.
The Python interface is similar to python-memcached.

pylibmc leverages configurable behaviors, data pickling, data
compression, tested GIL retention, consistent distribution, and the
binary memcached protocol.

%prep
%setup -q -n pylibmc-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
if [ -f %{_sbindir}/memcached ]; then
  %{_sbindir}/memcached &
elif [ -f %{_bindir}/memcached ]; then
  %{_bindir}/memcached &
else
  echo "Failed to start memcached - tests can't pass"
  exit 1
fi
pid=$!
%pytest_arch
kill $pid

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/pylibmc
%{python_sitearch}/_pylibmc*.so
%{python_sitearch}/pylibmc-%{version}*-info

%changelog
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Tue Nov 22 2022 mmachova@suse.com
- Update to 1.6.3
  * Fix logger.warn() deprecation warnings
  * Modernize tests and test harness
  * Python 3.10 support
- Remove python-pylibmc-remove-nose.patch
* Fri Nov 18 2022 dimstar@opensuse.org
- Cope with memcached moving from sbindir to bindir and safeguard
  against non-existing memcached binary: it if can't be started,
  there is no reason to even attempt to run the test suite.
* Fri Dec 10 2021 steven.kowalik@suse.com
- Skip testGetMulti due to memcached throwing some errors.
* Tue Sep  8 2020 pgajdos@suse.com
- added patches
  https://github.com/lericson/pylibmc/pull/263
  + python-pylibmc-remove-nose.patch
* Tue Sep 10 2019 tchvatal@suse.com
- Update to 1.6.1:
  * no changelog provided
* Tue Mar 12 2019 jayvdb@gmail.com
- Remove bcond test
- Activate test suite
- Use %%license
- Update URL to GitHub repository
- Update to v1.6.0
* Sat Sep  2 2017 jengelh@inai.de
- Expand description.
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to version 1.5.2
  * Fixes critical memory leaks in common code paths
    introduced in 1.4.2.
  * Fixes a critical bug in a corner of the zlib inflation code,
    where prior memory errors would trigger a double free.
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Mon May 11 2015 benoit.monin@gmx.fr
- update to version 1.4.2:
  * no changelog available
- additional changes from version 1.4.0:
  * Python 3.x support
  * miscellaneous bug fixes
  * testing improvements
  * documentation updates
- additional changes from version 1.3.0:
  * Added touch support
  * Added compress_level
  * Added weighted distribution
  * Added automated benchmarking utility
  * Added Travis CI and build status
  * Added behavior dead_timeout
  * Added behaviors tcp_keepalive
  * Added behavior callback_prefix_key
  * Lots of bug tuning, fixes, tests, and documentation
- remove LICENSE from package: not provided anymore
* Wed Sep 18 2013 speilicke@suse.com
- Fix license spelling
* Fri Aug  9 2013 speilicke@suse.com
- Fix license (SPDX style)
* Fri Aug  9 2013 speilicke@suse.com
- Initial version
